@@ -1,8 +1,6 @@
 #' @title Plot Pearson's Chi2-Test of multiple contingency tables
 #' @name sjp.chi2
 #'
-#' @seealso \href{http://talesofr.wordpress.com/2013/05/05/ridiculously-photogenic-factors-heatmap-with-p-values/}{Tales of R}.
-#'
 #' @description Plot p-values of Pearson's Chi2-tests for multiple contingency tables as ellipses or tiles.
 #'                Requires a data frame with dichotomous (dummy) variables.
 #'                Calculation of Chi2-matrix taken from
@@ -28,6 +26,7 @@
 #' sjp.chi2(mydf, axis.labels = items)
 #'
 #' @import ggplot2
+#' @importFrom grDevices rgb
 #' @importFrom dplyr bind_rows
 #' @export
 sjp.chi2 <- function(df,
@@ -89,9 +88,9 @@ sjp.chi2 <- function(df,
     geom_tile() +
     scale_x_discrete(labels = axis.labels) +
     scale_y_discrete(labels = axis.labels) +
-    scale_fill_gradient2(low = rgb(128, 205, 193, maxColorValue = 255),
+    scale_fill_gradient2(low = grDevices::rgb(128, 205, 193, maxColorValue = 255),
                          mid = "white",
-                         high = rgb(5, 113, 176, maxColorValue = 255),
+                         high = grDevices::rgb(5, 113, 176, maxColorValue = 255),
                          midpoint = 0.05) +
     geom_text(label = sprintf("%.3f", m$p.value)) +
     labs(title = title,
